Get the function parameters based on the selected function description
Source:R/plot-helpers.R
get_input_params.RdGet the function parameters based on the selected function description
Examples
ls <- mtcars |>
default_parsing() |>
dplyr::pull(mpg) |>
possible_plots() |>
(\(.x){
.x[[1]]
})() |>
get_input_params()
#> Error in available_plots(): object 'i18n' not found